@@ -21,6 +21,8 @@ from .Gallery import Gallery
 from .LinearGauge import LinearGauge
 from .List import List
 from .LoadPanel import LoadPanel
+from .Loading import Loading
+from .Loading2 import Loading2
 from .Lookup import Lookup
 from .NumberBox import NumberBox
 from .PieChart import PieChart
@@ -63,6 +65,8 @@ __all__ = [
     "LinearGauge",
     "List",
     "LoadPanel",
+    "Loading",
+    "Loading2",
     "Lookup",
     "NumberBox",
     "PieChart",
